callback property
A Function called when the provider button is pressed.
It must return null on success, or a String describing the error on failure.
Implementation
final ProviderAuthCallback? callback;
A Function called when the provider button is pressed.
It must return null on success, or a String describing the error on failure.
final ProviderAuthCallback? callback;